---
name: Critical Vulnerability Report
about: Critical vulnerability reports about the Raiden Network
---

# DO NOT use Github

If the issue you want to report is a critical vulnerability, something that may lead to lock up or loss of funds for Raiden users, then please do not use the public issue tracker.

Instead send an email with a detailed report to bounty@raiden.network.
<!-- TODO: Also add a link to the bug bounty website rules here. -->
